/*	$Id: envDefs.h,v 1.12 1995/04/24 16:01:20 anj Exp $	
 *	Author:	Roger A. Cole
 *	Date:	07-20-91
 *
 *	Experimental Physics and Industrial Control System (EPICS)
 *
 *	Copyright 1991, the Regents of the University of California,
 *	and the University of Chicago Board of Governors.
 *
 *	This software was produced under  U.S. Government contracts:
 *	(W-7405-ENG-36) at the Los Alamos National Laboratory,
 *	and (W-31-109-ENG-38) at Argonne National Laboratory.
 *
 *	Initial development by:
 *		The Controls and Automation Group (AT-8)
 *		Ground Test Accelerator
 *		Accelerator Technology Division
 *		Los Alamos National Laboratory
 *
 *	Co-developed with
 *		The Controls and Computing Group
 *		Accelerator Systems Division
 *		Advanced Photon Source
 *		Argonne National Laboratory
 *
 * Modification Log:
 * -----------------
 * .01	07-20-91	rac	initial version
 * .02  08-07-91	joh	added ioc log env
 * .03  09-26-94	joh	ifdef out double inclusion	
 * .04  11-28-94	joh	new CA env var 
 * .05  04-20-95	anj	moved defaults to CONFIG_ENV
 *
 * make options
 *	-DvxWorks	makes a version for VxWorks
 *	-DNDEBUG	don't compile assert() checking
 *      -DDEBUG         compile various debug code, including checks on
 *                      malloc'd memory
 */
/*+/mod***********************************************************************
* TITLE	envDefs.h - definitions for environment get/set routines
*
* DESCRIPTION
*	This file defines the environment parameters for EPICS.  These
*	ENV_PARAM's are initialized by $epics/share/bin/envSetupParams for
*	use by EPICS programs running under UNIX and VxWorks.
*
*	User programs can define their own environment parameters for their
*	own use--the only caveat is that such parameters aren't automatically
*	setup by EPICS.
*
* SEE ALSO
*	$epics/share/bin/envSetupParams, envSubr.c
*
*-***************************************************************************/

#ifndef envDefsH
#define envDefsH

typedef struct envParam {
    char	*name;		/* text name of the parameter */
    char	dflt[80];	/* default value for the parameter */
} ENV_PARAM;

extern ENV_PARAM EPICS_CA_ADDR_LIST; 
extern ENV_PARAM EPICS_CA_CONN_TMO; 
extern ENV_PARAM EPICS_CA_BEACON_PERIOD; 
extern ENV_PARAM EPICS_CA_AUTO_ADDR_LIST;
extern ENV_PARAM EPICS_CA_REPEATER_PORT;
extern ENV_PARAM EPICS_CA_SERVER_PORT;
extern ENV_PARAM EPICS_TS_MIN_WEST;
extern ENV_PARAM EPICS_IOC_LOG_PORT;
extern ENV_PARAM EPICS_IOC_LOG_INET;
extern ENV_PARAM EPICS_IOC_LOG_FILE_LIMIT;
extern ENV_PARAM EPICS_IOC_LOG_FILE_NAME;
extern ENV_PARAM EPICS_CMD_PROTO_PORT;
extern ENV_PARAM EPICS_AR_PORT;


char *envGetConfigParam();
long envPrtConfigParam();
long envSetConfigParam();
long envGetInetAddrConfigParam();
long envGetDoubleConfigParam();
long envGetLongConfigParam();

#endif /*envDefsH*/

